@@ -1,85 +1,67 @@
 from typing import List, Union
-from typing_extensions import Literal
-from uuid import UUID
 
-from dapodik import __semester__
-from dapodik.base import BaseDapodik, Message, UID
+from dapodik.base import BaseDapodik, DapodikMessage
 from dapodik.rest import TingkatPendidikan
-from . import (
-    AnggotaRombel,
-    Pembelajaran,
-    RombelPortal,
-    RombonganBelajar,
-)
+from dapodik.version import __semester__
 
-__fetch__ = (
-    AnggotaRombel,
-    Pembelajaran,
-    RombelPortal,
-    RombonganBelajar,
-)
+from . import AnggotaRombel
+# from . import Pembelajaran
+from . import RombelPortal
+from . import RombonganBelajar
 
 
 class BaseRombonganBelajar(BaseDapodik):
-    def __add_rombongan_belajar__(self) -> None:
-        self.__all__ += __fetch__
-
     def anggota_rombel(
         self,
-        rombongan_belajar_id: Union[UUID, str],
+        rombongan_belajar_id: str,
         page: int = 1,
         start: int = 0,
-        limit: Union[int, Literal["unlimited"]] = 25,
+        limit: Union[int, str] = 25,
     ) -> List[AnggotaRombel]:
         """Mengammbil data-data anggota rombel
-
         Args:
             rombongan_belajar_id (Union[UUID, str]): ID rombongan belajar
             page (int, optional): Halaman data ke. Defaults to 1.
             start (int, optional): Mulai dari. Defaults to 0.
-            limit (Union[int, Literal[, optional): Batas data yang dikembalikan. Defaults to 25.
-
+            limit (int, str, optional): Batas data yang dikembalikan. Defaults to 25. int atau unlimited
         Returns:
             List[AnggotaRombel]: list dari AnggotaRombel
         """
-        url = "allanggotarombel/" + str(rombongan_belajar_id)
-        res = self._get_rest(
-            url,
+        return self._get_rest(
+            path="allanggotarombel/" + str(rombongan_belajar_id),
+            cl=List[AnggotaRombel],
             page=page,
             start=start,
             limit=limit,
             prefix="customrest/",
+            key=lambda x: x,
         )
-        return self._fl(AnggotaRombel, res.json())
 
     def rombel_portal(
         self,
-        sekolah_id: UID,
+        sekolah_id: str,
         page: int = 1,
         start: int = 0,
         limit: int = 25,
     ) -> List[RombelPortal]:
         """rombel_portal dashboard
-
         Args:
             sekolah_id (UID): ID sekolah
             page (int, optional): Halaman ke. Defaults to 1.
             start (int, optional): Mulai dari. Defaults to 0.
             limit (int, optional): Batas data yang dikembalikan. Defaults to 25.
-
         Returns:
             List[RombelPortal]: list dari RombelPortal
         """
-        params = dict(sekolah_id=sekolah_id)
-        res = self._get_rest(
-            "RombelPortal",
-            params,
-            page,
-            start,
-            limit,
+        return self._get_rest(
+            path="RombelPortal",
+            cl=List[RombelPortal],
+            page=page,
+            start=start,
+            limit=limit,
+            query={"sekolah_id": sekolah_id},
             prefix="customrest/",
         )
-        return self._fl(RombelPortal, res.json())
 
     def rombongan_belajar(
         self,
@@ -89,12 +71,11 @@ class BaseRombonganBelajar(BaseDapodik):
         callback: str = "rombonganbelajar",
         jenis_rombel: str = "#IN1,5,6,7,8,9,10",
         sks=0,
-        limit: Union[int, Literal["unlimited"]] = "unlimited",
+        limit: Union[int, str] = "unlimited",
         page: int = 1,
         start: int = 0,
     ) -> List[RombonganBelajar]:
         """Mengammbil data-data rombongan belajar
-
         Args:
             sekolah_id (str): ID sekolah
             semester_id (str, optional): ID semester. Defaults to __semester__.
@@ -105,7 +86,6 @@ class BaseRombonganBelajar(BaseDapodik):
             limit (Union[int, Literal[, optional): Batas data yang dikembalikan. Defaults to "unlimited".
             page (int, optional): Halaman data-data yang diambil. Defaults to 1.
             start (int, optional): Mulai. Defaults to 0.
-
         Returns:
             List[RombonganBelajar]: list dari RombonganBelajar
         """
@@ -116,29 +96,32 @@ class BaseRombonganBelajar(BaseDapodik):
             "callback": callback,
             "jenis_rombel": jenis_rombel,
             "sks": sks,
+            "page": page,
+            "start": start,
+            "limit": limit,
         }
-        res = self._get_rest("RombonganBelajar", params, page, start, limit)
-        data: dict = res.json()
-        return self._fr(RombonganBelajar, data)
+        return self._get_rest(
+            path="RombonganBelajar",
+            cl=List[RombonganBelajar],
+            query=params,
+        )
 
     def kenaikan_kelas(
-        self, rombongan_belajar_id: Union[UUID, str], semester_id: str = __semester__
-    ) -> Message:
+        self, rombongan_belajar_id: str, semester_id: str = __semester__
+    ) -> DapodikMessage:
         """kenaikan_kelas rombongan belajar
-
         Args:
             rombongan_belajar_id (Union[UUID, str]): ID dari rombongan belajar
             semester_id (str, optional): Naikkan ke semester. Defaults dapodik.__semester__.
-
         Returns:
-            Message: Pesan sukses / tidak
+            DapodikMessage: Pesan sukses / tidak
         """
         data = dict(
             rombongan_belajar_id=rombongan_belajar_id,
             semester_id=semester_id,
         )
         res = self._post("kenaikankelas", data)
-        return self._msg(res.json())
+        return DapodikMessage.from_str(res.text)
 
     def filter_tingkat_pendidikan(
         self,
@@ -150,7 +133,6 @@ class BaseRombonganBelajar(BaseDapodik):
         limit: int = 50,
     ) -> List[TingkatPendidikan]:
         """filter_tingkat_pendidikan [summary]
-
         Args:
             fromui (str, optional): Misal tingkatpendidikanpaud. Defaults "".
             callback (str, optional): callback. Defaults "rombonganbelajar".
@@ -158,7 +140,6 @@ class BaseRombonganBelajar(BaseDapodik):
             page (int, optional): halaman. Defaults 1.
             start (int, optional): mulai. Defaults 0.
             limit (int, optional): batas. Defaults 50.
-
         Returns:
             List[TingkatPendidikan]: list dari TingkatPendidikan
         """
@@ -170,5 +151,8 @@ class BaseRombonganBelajar(BaseDapodik):
             "start": start,
             "limit": limit,
         }
-        res = self._get("filtertingkatpendidikan", params)
-        return self._fr(TingkatPendidikan, res.json())
+        return self._get_rest(
+            path="filtertingkatpendidikan",
+            cl=List[TingkatPendidikan],
+            query=params,
+        )
